Tutorials
=========
This page contains several examples of how martinize2 can be used to convert
proteins from atomistic to a martini3 representation.

You can find further examples on how to use martinize2 in the martinize-examples
repository: https://github.com/marrink-lab/martinize-examples

.. Organize the tutorials in directories, so it's easier to keep their files
    together

.. toctree::
    basic_usage
    elastic_networks
    go_models
    water_biasing
    mutations_and_modifications
    6_adding_residues_links/index
    7_adding_modifications/index
